@@ -10,5 +10,10 @@ from .FunctionGUI import (
     Button,
     Entry,
     GetEntry,
-    Run
+    Run,
+    BulleanVar,
+    ChexBox,
+    Add,
+    Design
+
 )
